@@ -1,5 +1,5 @@
 import requests
-from . import BASE_URL
+from . import BASE_URL, emoji
 
 
 def get_message(chat_id: int, key: str) -> str:
@@ -21,3 +21,15 @@ def get_available_language(lang: str = None):
     })
     key = r.json()["key"]
     return dict(key)
+
+
+kode = get_available_language()
+lang_flags = {
+    "en": f"{emoji.FLAG_UNITED_STATES} English",
+    "id": f"{emoji.FLAG_INDONESIA} Indonesia",
+    "jp": f"{emoji.FLAG_JAPAN} Japan",
+    "hi": f"{emoji.FLAG_INDIA} India",
+    "gj": f"{emoji.FLAG_INDIA} Gujarat",
+    "si": f"{emoji.FLAG_SRI_LANKA} Sinhala",
+    "ta": f"{emoji.FLAG_SRI_LANKA} Tamil"
+}
